#
# spec file for package uncrustify
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           uncrustify
Version:        0.80.1
Release:        1.1
Summary:        Source Code Beautifier for C, C++, C#, ObjectiveC, D
License:        GPL-2.0-or-later
Group:          Development/Languages/C and C++
URL:            https://github.com/uncrustify/uncrustify
Source:         https://github.com/%{name}/%{name}/archive/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++

%description
Source Code Beautifier for C, C++, C#, ObjectiveC, D, Java, Pawn and VALA.

Features:
  * Ident code, aligning on parens, assignments, etc.
  * Align on '=' and variable definitions.
  * Align structure initializers.
  * Align #define stuff.
  * Align backslash-newline stuff.
  * Reformat comments (a little bit).
  * Fix inter-character spacing.
  * Add or remove parens on return statements.
  * Add or remove braces on single-statement if/do/while/for statements.
  * Supports embedded SQL 'EXEC SQL' stuff.
  * Highly configurable - 454 configurable options as of version 0.60.

%prep
%setup -q -n %{name}-%{name}-%{version}

%build
%define build_args %{nil}
%if 0%{?suse_version} < 1600
%define build_args -DCMAKE_INSTALL_DOCDIR:PATH=%{_docdir}/%{name}
%endif
%cmake %{build_args}

%cmake_build

%install
%cmake_install
rm -rf %{buildroot}%{_docdir}/uncrustify

%files
%doc AUTHORS ChangeLog README.md documentation/* etc
%license COPYING
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}

%changelog
* Wed Dec  4 2024 Andrea Manzini <andrea.manzini@suse.com>
- update to 0.80.1:
  * Removed : sp_pragma_open_parenthesis
  * Removed : sp_inside_gparen
- update to 0.80.0:
  * Added   : sp_inside_gparen
  * Added   : sp_pragma_open_parenthesis
  * Added   : sp_struct_type
  * Added   : sp_emb_cmt_priority
* Thu Jul  4 2024 Dirk Müller <dmueller@suse.com>
- update to 0.79.0:
  * Added   : sp_cpp_before_struct_binding_after_byref
  * Added   : sp_string_string
  * Added   : pp_unbalanced_if_action
  * Removed : pp_warn_unbalanced_if
  * Removed : sp_balance_nested_parens
  * Added   : debug_print_version
  * Added   : nl_oc_msg_args_finish_multi_line
* Wed Feb 28 2024 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Align path for document installation between openSUSE versions.
* Fri Nov 24 2023 ming li <mli@suse.com>
- update to 0.78.1:
  * Improve line splitting logic to avoid awkward splits
* Sun Nov 19 2023 Dirk Müller <dmueller@suse.com>
- update to 0.78.0:
  * Added: align_nl_cont_spaces
  * Added: sp_after_bit_colon
  * Added: sp_before_bit_colon
  * Added: sp_between_ptr_ref
  * Added: nl_min_after_func_body
  * Added: sp_before_keyword_ptr_star
  * Added: sp_before_global_scope_ptr_star
  * Added: sp_before_scope_ptr_star
  * Added: sp_before_operator_ptr_star
  * Added: sp_before_qualifier_ptr_star
  * Removed: sp_before_keyword_ptr_star
  * Added: debug_use_the_exit_function_pop
  * Added: nl_max_after_func_body
  * Added: sp_cpp_lambda_argument_list_empty
  * Added: align_func_proto_span_ignore_cont_lines
* Wed May 24 2023 Dirk Müller <dmueller@suse.com>
- update to 0.77.1:
  * Added sp_cmt_cpp_pvs                       Jan 28 2023
  * Added sp_inside_rparen                     Feb 15 2023
  * Added sp_func_call_user_inside_rparen      Feb 15 2023
  * Added sp_inside_rparens                    Feb 15 2023
  * Added sp_cmt_cpp_lint                      Mar 18 2023
  * Added sp_qualifier_ptr_star_trailing       Apr 13 2023
  * Added sp_qualifier_unnamed_ptr_star        Apr 13 2023
  * Added sp_qualifier_ptr_star_func           Apr 13 2023
  * Added mod_add_force_c_closebrace_comment   Apr 19 2023
* Tue Dec  6 2022 Dirk Müller <dmueller@suse.com>
- update to 0.76.0:
    Added   : nl_collapse_empty_body_functions     Apr 29 2022
    Added   : set_numbering_for_html_output        May 29 2022
    Added   : mod_infinite_loop                    Jun 22 2022
    Added   : mod_short_int                        Jun 28 2022
    Added   : mod_long_int                         Jun 28 2022
    Added   : mod_unsigned_int                     Jun 28 2022
    Added   : mod_signed_int                       Jun 28 2022
    Added   : mod_int_prefer_int_on_left           Jul  6 2022
    Added   : mod_int_long                         Jul  6 2022
    Added   : mod_int_signed                       Jul  6 2022
    Added   : mod_int_unsigned                     Jul  6 2022
    Added   : mod_int_short                        Jul  6 2022
    Added   : nl_oc_msg_args_min_params            Jul  9 2022
    Added   : pp_space_after                       Jul 14 2022
    Added   : pp_space_before                      Jul 14 2022
    Removed : pp_space                             Jul 14 2022
    Added   : nl_throw_expr                        Jul 19 2022
    Added   : mod_paren_on_throw                   Jul 19 2022
    Added   : debug_sort_the_tracks                Aug  2 2022
    Removed : pp_space_before                      Aug  6 2022
    Added   : nl_var_def_blk_end_func_top          Aug 11 2022
    Removed : nl_func_var_def_blk                  Aug 11 2022
    Added   : pp_indent_with_tabs                  Sep  6 2022
    Added   : pp_multiline_define_body_indent      Sep 15 2022
    Added   : nl_oc_msg_args_max_code_width        Sep 20 2022
    Added   : debug_decode_the_flags               Oct  9 2022
* Tue May 17 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.75.1
  * Added mod_move_case_return
  * Added sp_ptr_star_func_type
  * Added pp_indent_at_level0
  * Added align_braced_init_list_thresh
  * Added align_braced_init_list_span
  * Added align_assign_on_multi_var_defs
  * Added sp_byref_paren
  * Added sp_not_not
  * Added indent_ignore_comma_paren
  * Added indent_ignore_comma_brace
  * Added indent_ignore_bool_paren
  * Added indent_ignore_arith
  * Added mod_full_paren_return_bool
  * Added mod_full_paren_assign_bool
  * Added sp_type_colon
  * Removed indent_ignore_comma_paren
  * Removed indent_ignore_bool_paren
  * Removed indent_ignore_comma_brace
  * Added indent_ignore_semicolon
  * Added sp_enum_brace
  * Added indent_ignore_before_class_colon
  * Added indent_ignore_before_constr_colon
  * Added indent_ignore_bool
  * Added indent_ignore_first_continue
  * Added indent_ignore_assign
  * Added indent_ignore_case_brace
  * Added indent_namespace_inner_only
  * Added pp_warn_unbalanced_if
  * Removed sp_type_question
* Mon Dec 20 2021 Dirk Müller <dmueller@suse.com>
- update to 0.74.0
  * Added nl_before_struct
  * Added nl_before_ignore_after_case
  * Added sp_before_ptr_star_trailing
  * Added sp_after_ptr_star_trailing
  * Added sp_sparen_paren
  * Added pp_indent_in_guard
  * Added indent_single_line_comments_before
  * Added indent_single_line_comments_after
  * Removed indent_sing_line_comments
  * Added sp_after_ellipsis
  * Added mod_remove_duplicate_include
  * Added sp_between_semi_for_empty
  * Added nl_before_brace_open
  * Added cmt_trailing_single_line_c_to_cpp
  * Added sp_ellipsis_parameter_pack
  * Added sp_parameter_pack_ellipsis
  * Added sp_byref_ellipsis
  * Added sp_ptr_type_ellipsis
  * Added indent_ctor_init_following
  * Added sp_before_emb_cmt
  * Added sp_num_after_emb_cmt
  * Added sp_before_tr_cmt
  * Added sp_num_before_emb_cmt
  * Added sp_num_before_tr_cmt
  * Added sp_after_emb_cmt
  * Removed sp_before_tr_emb_cmt
  * Removed sp_num_before_tr_emb_cmt
  * Added pp_include_at_level
  * Added sp_return
  * Added indent_comment_align_thresh
  * Added indent_comment
  * Added align_func_proto_amp_style
  * Added align_func_proto_star_style
  * Added indent_case_comment
  * Added indent_switch_body
  * Added sp_inside_for_close
  * Added sp_inside_for
  * Added sp_inside_for_open
  * Added indent_ignore_label
  * Added sp_ptr_star_func_var
* Thu Jul  1 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 0.73.0
  * Added indent_before_class_colon
  * Added sp_cmt_cpp_region
  * Added cmt_sp_before_doxygen_javadoc_tags
  * Added cmt_align_doxygen_javadoc_tags
  * Added cmt_reflow_fold_regex_file
  * Added processing_cmt_as_regex
  * Added cmt_reflow_indent_to_paragraph_start
  * Added sp_cpp_lambda_argument_list
  * Added nl_do_leave_one_liners
  * Added debug_truncate
  * Added indent_comma_brace
* Mon Jan  4 2021 Dirk Müller <dmueller@suse.com>
- update to 0.72.0:
  * new command option: --debug-csv-format : Dump debug info to file in csv-delimited format.
  * Added: nl_inside_empty_func
  * Added: debug_timeout
  * Added: sp_inside_square_empty
  * Added: align_eigen_comma_init
  * Added: pos_shift
  * Added: donot_indent_func_def_close_paren
  * Added: donot_add_nl_before_cpp_comment
  * see https://github.com/uncrustify/uncrustify/blob/uncrustify-0.72.0/ChangeLog
* Thu May 14 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 0.71.0:
  * Changes too numerous to list, see ChangeLog
* Sun Feb 18 2018 aloisio@gmx.com
- Update to version 0.66.1
  * Changes too numerous to list, see ChangeLog
- Switched to cmake build
* Fri May  8 2015 adam@mizerski.pl
- update to 0.61
  - no entry in changelog
* Tue Jul 15 2014 adam@mizerski.pl
- new package (version 0.60)
